import * as React from 'react';
import { TextOverflow } from '../TextOverflow/TextOverflow';
export type ButtonRequiredProps = {
    /** callback */
    onClick: (e: React.SyntheticEvent<HTMLDivElement>) => void;
    /** can be a String, or a dictionary { [buttonState]: String }, t.maybe(t.union([t.Str,  stringForButtonStates]) */
    label?: string | Button.ButtonStateMap<string>;
    /** otherwise just pass a string as children */
    children?: string;
    /** type of the button (default, primary, positive, negative, flat) */
    type?: Button.ButtonType;
    /** shortcut for type "flat" */
    flat?: boolean;
    /** can be a component referring to an Icon, or a dictionary { [buttonState]: JSX.Element } */
    icon?: JSX.Element | Button.ButtonStateMap<JSX.Element>;
};
export type ButtonDefaultProps = {
    /** function to handle the overflow of too long labels, replacing with ellipsed string and tooltip */
    textOverflow: Button.TextOverflowCompatibleComponent;
    /** ready, not-allowed, processing, success, error; overrides `baseState`, use it if you want button to be a functional component */
    buttonState: Button.ButtonState;
    /** size of the button, one of 'tiny', 'small', 'medium' */
    size: Button.ButtonSize;
    /** fluid (block) button, takes the width of the container */
    fluid: boolean;
    /** shortcut for type "primary" */
    primary: boolean;
    /** circular button, this is allowed only if it's an icon button */
    circular: boolean;
    /** an optional class name to pass to first inner element of the component */
    className: string;
    /** an optional style object to pass to first inner element of the component */
    style: React.CSSProperties;
};
export declare namespace Button {
    type TextOverflowCompatibleComponent = React.ComponentClass<TextOverflow.Props>;
    type ButtonStateMap<T> = {
        [key in Button.ButtonState]?: T;
    };
    type ButtonState = 'ready' | 'not-allowed' | 'processing' | 'error' | 'success';
    type ButtonType = 'default' | 'primary' | 'positive' | 'negative' | 'flat';
    type ButtonSize = 'tiny' | 'small' | 'medium';
    type Props = ButtonRequiredProps & Partial<ButtonDefaultProps>;
}
export declare class Button extends React.PureComponent<Button.Props> {
    static defaultProps: ButtonDefaultProps;
    componentDidMount(): void;
    templateLoading: () => JSX.Element;
    templateIcon: (icon: JSX.Element) => JSX.Element;
    templateLabel: (label: string, TextOverflow: Button.TextOverflowCompatibleComponent) => JSX.Element;
    render(): JSX.Element;
}
