import 'react-dates/initialize';
import * as React from 'react';
import moment from 'moment';
import { LocalDate } from 'local-date';
export declare namespace DatePicker {
    type Props = {
        /** an optional id to pass to top level element of the component */
        id?: string;
        /** default date */
        defaultValue?: LocalDate;
        /** called when datepicker is closed */
        onHide?: () => void;
        /** MomentJS format used to display current date */
        displayFormat?: string;
        /** minimum date selectable by the user */
        minDate?: LocalDate;
        /** maximum date selectable by the user */
        maxDate?: LocalDate;
        /** if set, the datepicker will highlight days in the range starting from this date and ending to the hovered or selected date */
        fromDate?: LocalDate;
        /** if set, the datepicker will highlight days in the range starting from the hovered or selected date to this value */
        toDate?: LocalDate;
        /** whether the datepicker should be rendered above or below the input field */
        position?: 'up' | 'down';
        /** whether the input box should be small or not */
        small?: boolean;
        /** the icon to show in the input field */
        icon?: JSX.Element;
        /** specify an initial "visible" date with no need to select a defaultValue */
        startDate?: LocalDate;
        /** locale used for translations */
        locale?: string;
        /** pass true if you want the datepicker to close automatically after the user selects a value */
        autoClose?: boolean;
        /** whether the datepicker should be disabled or not */
        disabled?: boolean;
        /** called when the focus changes */
        onFocusChange?: (focus: boolean) => void;
        /** an optional class name to pass to top level element of the component */
        className?: string;
        /** an optional style object to pass to top level element of the component */
        style?: React.CSSProperties;
    } & ({
        /** whether the user can remove the selected date */
        isClearable: true;
        /** current date */
        value: LocalDate | null;
        /** called when value changes */
        onChange?: (date: LocalDate | null) => void;
    } | {
        isClearable?: false;
        value: LocalDate;
        onChange?: (date: LocalDate) => void;
    });
}
export type State = {
    value: moment.Moment | null;
    hoveredDay?: moment.Moment;
    focused: boolean;
};
/**
 * A decent and pretty date picker to be used with React
 */
export declare class DatePicker extends React.PureComponent<DatePicker.Props, State> {
    dayRenderer: (day: moment.Moment) => JSX.Element;
    componentWillMount(): void;
    componentDidUpdate(prevProps: DatePicker.Props): void;
    state: {
        value: moment.Moment | null;
        hoveredDay: undefined;
        focused: boolean;
    };
    _onChange: (value: moment.Moment | null) => void;
    isDayBlocked: (day: moment.Moment) => boolean;
    initialVisibleMonth: () => moment.Moment;
    onFocusChange: ({ focused }: {
        focused: boolean | null;
    }) => void;
    onDayMouseEnter: (day: moment.Moment) => () => void;
    onDayMouseLeave: () => void;
    isInRange: (day: moment.Moment, referenceDay?: moment.Moment | null) => boolean | null | undefined;
    getDayClass: (day: moment.Moment) => string;
    dayRendererFactory(): (day: moment.Moment) => JSX.Element;
    onClose: () => void;
    render(): JSX.Element;
}
