/// <reference types="lodash" />
import * as React from 'react';
import { Children } from '../utils';
export type FocusableViewRequiredProps = {
    /** FocusableView content. If a function it gets called with the boolean "focused" */
    children: ((focused: boolean) => Children) | Children;
    /** Debounce onFocus/onBlur events of x millis */
    debounce?: number;
    className?: string;
    style?: React.CSSProperties;
};
export type FocusableViewDefaultProps = {
    /** When `true` the class "focused" is NOT added */
    ignoreFocus: boolean;
    /** Callback function called on "focus" event */
    onFocus: () => void;
    /** Callback function called on "blur" event */
    onBlur: () => void;
    /** "tabindex" attribute */
    tabIndex: number;
    /** Wrapper component for `children` */
    component: keyof React.ReactHTML | React.ComponentClass<{}>;
};
export declare namespace FocusableView {
    type Props = Partial<FocusableViewDefaultProps> & FocusableViewRequiredProps;
}
type FocusableViewDefaultedProps = FocusableViewRequiredProps & FocusableViewDefaultProps;
/**
 * A panel that can get focus
 */
export declare class FocusableView extends React.Component<FocusableView.Props> {
    static defaultProps: FocusableViewDefaultProps;
    defaultedProps: () => FocusableViewDefaultedProps;
    state: {
        focused: boolean;
    };
    _mounted: boolean;
    componentDidMount(): void;
    componentWillUnmount(): void;
    _onFocus: () => void;
    _onBlur: () => void;
    _onFocusBlurEvent: (type: string) => void;
    onFocusBlurEventDebounced: ((type: string) => void) & _.Cancelable;
    onFocusBlurEvent: ({ type }: React.FocusEvent<HTMLElement>) => void;
    render(): React.DetailedReactHTMLElement<React.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>;
}
export {};
