import * as React from 'react';
import View from 'react-flexview';
import Popover from '../Popover';
import { ObjectOmit } from '../utils';
export declare namespace FormField {
    type Props = {
        /** the label for the field */
        label: JSX.Element | string;
        /** whether the field is required */
        required?: boolean;
        /** whether the field is disabled */
        disabled?: boolean;
        /** the input component to wrap */
        render: (onFocus: () => void, onBlur: () => void) => JSX.Element;
        /** optional props to pass to the wrapping View */
        viewProps?: View.Props;
        /** wheter the label should be put on the same line of the component */
        horizontal?: boolean;
        /** optional callback when the field label is clicked */
        onLabelClick?: () => void;
        /** an optional class name to pass to top level element of the component */
        className?: string;
        /** an optional style object to pass to top level element of the component */
        style?: React.CSSProperties;
        /** an optional id to pass to top level element of the component */
        id?: string;
        /** an optional hint describing what's the expected value for the field (e.g. sample value or short description) */
        hint?: {
            content: NonNullable<React.ReactElement>;
            type: 'box' | 'label';
        } | {
            content: NonNullable<React.ReactElement>;
            type: 'tooltip';
            popover?: ObjectOmit<Popover.Props['popover'], 'content'>;
        };
    };
}
type State = {
    focused: boolean;
    mouseover: boolean;
};
export declare class FormField extends React.PureComponent<FormField.Props, State> {
    state: State;
    stateChange: <K extends keyof State>(k: K, value: State[K]) => () => void;
    renderFieldWithHint: (render: FormField.Props['render'], hint: FormField.Props['hint']) => JSX.Element;
    render(): JSX.Element;
}
export {};
