import * as React from 'react';
import { ActionsMenu } from './ActionsMenu';
import { Popover } from '../Popover/Popover';
export type MenuRequiredProps = {
    /** custom content for the menu trigger */
    children?: JSX.Element | string;
    /** custom renderer for menu items. if none is passed, it renders ActionsMenu */
    menuRenderer?: (options: ActionsMenu.Option[]) => JSX.Element;
    /** menu options */
    options: ActionsMenu.Option[];
    /** called when menu is opened */
    onOpen: () => void;
    /** called when menu is closed */
    onClose: () => void;
    /** set of built-in max heights for the menu (if maxHeight is passed, this is ignored) */
    size?: Menu.Size;
    /** custom max height for the menu */
    maxHeight?: number;
    className?: string;
};
export type MenuDefaultProps = {
    /** whether the menu is open or not */
    isOpen: boolean;
    /** whether the menu should be closed when clicking outside */
    dismissOnClickOutside: boolean;
    /** whether the menu should be rendered on top or at the bottom of the trigger (bottom by default) */
    position: 'top' | 'bottom';
    /** whether the menu should be aligned with the start, the end or the center of the trigger (end by default) */
    anchor: Popover.Props['popover']['anchor'];
};
export declare namespace Menu {
    type Size = 'small' | 'medium' | 'large';
    type Props = MenuRequiredProps & Partial<MenuDefaultProps>;
}
/**
 *  A menu with actions
 */
export declare class Menu extends React.PureComponent<Menu.Props> {
    getActionsMenuMaxHeight: () => number | undefined;
    render(): JSX.Element;
}
