"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Meter = void 0;
var React = __importStar(require("react"));
var log_1 = require("../utils/log");
var classnames_1 = __importDefault(require("classnames"));
var react_flexview_1 = __importDefault(require("react-flexview"));
var find = require("lodash/find");
var every = require("lodash/every");
var some = require("lodash/some");
var isEqual = require("lodash/isEqual");
var sortBy = require("lodash/sortBy");
function noOverlappingRanges(rangeList) {
    var isOverlapped = function (range1, range2) {
        return Math.max(range1.startValue, range2.startValue) < Math.min(range1.endValue, range2.endValue);
    };
    var noOverlappingRanges = function (ranges) {
        return every(ranges, function (range1, i) {
            return every(ranges.slice(0, i).concat(ranges.slice(i + 1)), function (range2) {
                return !isOverlapped(range1, range2);
            });
        });
    };
    return noOverlappingRanges(rangeList);
}
var isFullyFilled = function (ranges, min, max) {
    if (!ranges) {
        return false;
    }
    var comparableRanges = ranges.concat({ startValue: max, endValue: min });
    var sortedStartValueList = sortBy(comparableRanges, 'startValue').map(function (range) { return range.startValue; });
    var sortedEndValueList = sortBy(comparableRanges, 'endValue').map(function (range) { return range.endValue; });
    return isEqual(sortedStartValueList, sortedEndValueList);
};
var computePercentage = function (value, min, max) {
    return Math.abs(((value - min) * 100) / (max - min));
};
var labelFormatter = function (value, min, max) {
    return "".concat(computePercentage(value, min, max), "%");
};
/**
 * A Meter displays a measurement (usually a percentage) on a known scale.
 */
var Meter = /** @class */ (function (_super) {
    __extends(Meter, _super);
    function Meter() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.logWarnings = function () {
            var _a = _this
                .props, ranges = _a.ranges, max = _a.max, min = _a.min, baseFillingColor = _a.baseFillingColor, baseBackgroundColor = _a.baseBackgroundColor;
            (0, log_1.warn)(function () {
                if (min >= max) {
                    return 'min should be less than max';
                }
                return undefined;
            });
            (0, log_1.warn)(function () {
                if (some(ranges, function (r) { return r.startValue >= r.endValue; })) {
                    return 'malformed range received (startValue >= endValue)';
                }
                return undefined;
            });
            (0, log_1.warn)(function () {
                if (ranges && !noOverlappingRanges(ranges)) {
                    return 'some ranges overlap';
                }
                return undefined;
            });
            (0, log_1.warn)(function () {
                if (isFullyFilled(ranges, min, max) && (baseFillingColor || baseBackgroundColor)) {
                    return 'baseFillingColor or baseBackgroundColor is not needed, ranges are fully filled';
                }
                return undefined;
            });
            (0, log_1.warn)(function () {
                if (!(isFullyFilled(ranges, min, max) || (baseFillingColor && baseBackgroundColor))) {
                    return 'You should pass both baseFillingColor and baseBackgroundColor, ranges are not fully filled';
                }
                return undefined;
            });
        };
        _this.computeStyles = function () {
            var _a = _this
                .props, value = _a.value, min = _a.min, max = _a.max, ranges = _a.ranges, baseFillingColor = _a.baseFillingColor, baseLabelColor = _a.baseLabelColor, baseBackgroundColor = _a.baseBackgroundColor;
            var range = find(ranges, function (_a) {
                var startValue = _a.startValue, endValue = _a.endValue;
                return value >= startValue && value <= endValue;
            });
            return {
                basisSize: "".concat(computePercentage(value, min, max), "%"),
                fillingStyle: {
                    background: (range && range.fillingColor) || baseFillingColor
                },
                labelStyle: {
                    color: (range && range.labelColor) || baseLabelColor
                },
                barStyle: {
                    background: (range && range.backgroundColor) || baseBackgroundColor
                }
            };
        };
        return _this;
    }
    Meter.prototype.componentDidMount = function () {
        this.logWarnings();
    };
    Meter.prototype.render = function () {
        var _a = this
            .props, id = _a.id, style = _a.style, _className = _a.className, labelFormatter = _a.labelFormatter, value = _a.value, min = _a.min, max = _a.max;
        var _b = this.computeStyles(), basisSize = _b.basisSize, fillingStyle = _b.fillingStyle, labelStyle = _b.labelStyle, barStyle = _b.barStyle;
        var className = (0, classnames_1.default)('meter', _className);
        var formattedLabel = labelFormatter(value, min, max);
        return (React.createElement(react_flexview_1.default, __assign({}, { id: id, className: className, style: style }, { grow: true, vAlignContent: "center" }),
            React.createElement(react_flexview_1.default, { className: "bar", grow: true, style: barStyle },
                React.createElement(react_flexview_1.default, { className: "filling", basis: basisSize, style: fillingStyle })),
            React.createElement(react_flexview_1.default, { className: "label", shrink: false, style: labelStyle }, formattedLabel)));
    };
    Meter.defaultProps = {
        min: 0,
        max: 100,
        labelFormatter: labelFormatter
    };
    return Meter;
}(React.PureComponent));
exports.Meter = Meter;
