import * as React from 'react';
import { Children } from '../utils';
import { PanelHeader } from './PanelHeader';
export type PanelDefaultProps = {
    style: React.CSSProperties;
    /** whether it's loading or not */
    loading: boolean;
    /** soft loading */
    softLoading: boolean;
    /** soft loading delay */
    softLoadingDelay: number;
    /** true if it should use dark theme */
    dark: boolean;
};
export type PanelRequiredProps = {
    /** panel content */
    children: Children;
    /** The type of panel (docked or floating) */
    type: Panel.PanelType;
    /** header props (collapse, content, title, menu) */
    header?: Panel.Header;
    /** top | left | right | bottom */
    clearMargin?: Panel.ClearMargin;
    className?: string;
};
export type PanelDefaultedProps = PanelRequiredProps & PanelDefaultProps;
export declare namespace Panel {
    type PanelType = 'docked-top' | 'docked-left' | 'docked-bottom' | 'docked-bottom' | 'floating';
    type ClearMargin = 'top' | 'left' | 'bottom' | 'right';
    type Header = {
        collapse?: {
            direction: 'up' | 'left' | 'down' | 'right';
            onExpand: () => void;
            onCollapse: () => void;
            isCollapsed?: boolean;
        };
        size?: PanelHeader.Props['size'];
        content?: Children;
        title?: any;
        hideTitleWhenExpanded?: boolean;
        menu?: Children;
    };
    type Props = PanelRequiredProps & Partial<PanelDefaultProps>;
}
/** A simple component used to group elements in a box. */
export declare class Panel extends React.PureComponent<Panel.Props> {
    static defaultProps: PanelDefaultProps;
    _softLoadingActive: boolean;
    _softLoadingTimer: number | null;
    updateSoftLoadingState(prevSoftLoading: boolean): void;
    isSoftLoading(softLoading: boolean, softLoadingDelay: number): boolean;
    componentDidMount(): void;
    componentDidUpdate(oldProps: PanelDefaultedProps): void;
    componentWillUnmount(): void;
    toggleExpanded: () => void;
    getStyle: () => React.CSSProperties;
    templateSoftLoading: ({ softLoading, isExpanded }: {
        softLoading: boolean;
        isExpanded: boolean;
    }) => JSX.Element | null;
    templateHeader: ({ header, isExpanded, toggleExpanded }: {
        header?: Panel.Header | undefined;
        isExpanded: boolean;
        toggleExpanded: () => void;
    }) => JSX.Element | null;
    templateExpandedContent: ({ children, loading }: {
        children: Children;
        loading: boolean;
    }) => JSX.Element;
    templateCollapsedContent: ({ header, verticalDirection }: {
        header?: Panel.Header | undefined;
        verticalDirection?: boolean | undefined;
    }) => JSX.Element | null;
    render(): JSX.Element;
}
