import * as React from 'react';
import { Children } from '../utils';
export type State = {
    isOpen: boolean;
    popover?: Popover.PopoverElement;
    child?: Popover.PopoverElement;
};
export declare namespace Popover {
    export type Position = 'top' | 'bottom' | 'left' | 'right';
    export type Anchor = 'start' | 'center' | 'end';
    export type Event = 'click' | 'hover';
    export type Delay = number | {
        whenClosed?: number;
        whenOpen?: number;
    };
    export type PopoverSettings = {
        content: NonNullable<Children>;
        attachToBody?: boolean;
        auto?: boolean;
        position?: Position;
        anchor?: Anchor;
        event?: Event;
        onShow?: () => void;
        onHide?: () => void;
        onToggle?: () => void;
        dismissOnScroll?: boolean;
        dismissOnClickOutside?: boolean;
        className?: string;
        style?: React.CSSProperties;
        id?: string;
        maxWidth?: number | string;
        distance?: number;
        offsetX?: number;
        offsetY?: number;
        isOpen?: boolean;
        delay?: Delay;
        contextTypes?: React.ValidationMap<any>;
        context?: object;
    };
    type GetPopoverNonDefaultedProps = 'id' | 'maxWidth' | 'delay' | 'attachToBody' | 'auto' | 'style' | 'contextTypes' | 'context' | 'isOpen';
    export type GetPopoverPropsReturn = Required<Pick<Popover.PopoverSettings, Exclude<keyof Popover.PopoverSettings, GetPopoverNonDefaultedProps>>> & Pick<Popover.PopoverSettings, GetPopoverNonDefaultedProps>;
    export type PopoverElement = {
        width: number;
        height: number;
        x: number;
        y: number;
    };
    export type Props = {
        /** the trigger node. It's always visible */
        children: Children;
        /** popover settings. The popover is **not** always visible */
        popover: PopoverSettings;
        className?: string;
        style?: React.CSSProperties;
        id?: string;
    };
    export {};
}
type PopoverStyle = React.CSSProperties & {
    _computedAnchor?: Popover.Anchor;
    _computedPosition?: Popover.Position;
};
/**
 * Composed of two children: trigger (children) and popover. After a particular event on the trigger
 * (usually "hover" or "click") it renders the popover and positions it relative to it.
 */
export declare class Popover extends React.Component<Popover.Props, State> {
    private children;
    private initialized;
    private containerNode;
    private onMouseEventDebouncedWhenOpen;
    private onMouseEventDebouncedWhenClosed;
    private ContextWrapper;
    state: State;
    componentDidMount(): void;
    componentDidUpdate(prevProps: Popover.Props): void;
    componentWillUnmount(): void;
    addOnClickListener: () => void;
    removeOnClickListener: () => void;
    onClickOutside: (e: MouseEvent) => void;
    addOnScrollListener: () => void;
    removeOnScrollListener: () => void;
    onScroll: () => void;
    addListeners: () => void;
    removeListeners: () => void;
    getPopoverProps: (_props?: Popover.Props) => Popover.GetPopoverPropsReturn;
    getPopoverNode: () => Element | null;
    getOffsetRect: (target: Element) => {
        top: number;
        left: number;
    };
    saveValuesFromNodeTree: () => void;
    isStateful: (props?: Popover.Props) => boolean;
    isOpen: (props?: Popover.Props) => boolean | undefined;
    isEventInsideTarget: (el: Node, target: Node) => boolean;
    appendPopover: () => void;
    removePopover: () => void;
    onPopoverOpenChange: (props?: Popover.Props) => void;
    onPopoverStateChange: () => void;
    eventWrapper: <E extends React.SyntheticEvent<HTMLElement, Event>>(cb: (e: E) => void) => (e: E) => void;
    getDelayWhenClosed: (delay?: Popover.Delay) => number | undefined;
    getDelayWhenOpen: (delay?: Popover.Delay) => number | undefined;
    updateDebouncedMousedEvents: (nextProps?: Popover.Props) => void;
    _onMouseEvent: (type: string) => void;
    onMouseEvent: React.MouseEventHandler<any>;
    showPopover: () => void;
    hidePopover: () => void;
    togglePopover: () => void;
    setIsOpen: (isOpen: boolean) => void;
    popoverTemplate: ({ _computedAnchor, _computedPosition, ..._style }: PopoverStyle) => JSX.Element;
    getVisiblePopover: () => JSX.Element;
    getHiddenPopover: () => JSX.Element;
    isAbsolute: () => boolean;
    getEventCallbacks: () => {
        onMouseEnter: ((e: React.MouseEvent<any, MouseEvent>) => void) | undefined;
        onMouseLeave: ((e: React.MouseEvent<any, MouseEvent>) => void) | undefined;
        onClick: ((e: React.SyntheticEvent<HTMLElement, Event>) => void) | undefined;
    };
    computePopoverStyle: (position: Popover.Position, anchor: Popover.Anchor) => PopoverStyle;
    private getLocals;
    render(): JSX.Element;
}
export {};
