import * as React from 'react';
import { Children } from '../utils';
import { EasingType } from './easingFunctions';
export type ScrollViewDefaultProps = {
    /** enable horizontal scrolling */
    scrollX: boolean;
    /** enable vertical scrolling */
    scrollY: boolean;
    /** enable scroll propagation */
    scrollPropagation: boolean;
    /** easing function used when scrolling with `scrollTo` */
    easing: EasingType;
    /** onScroll function that handle onScroll events */
    onScroll: React.WheelEventHandler<HTMLDivElement>;
    style: React.CSSProperties;
};
export type ScrollTo = (_x?: number | null, _y?: number | null, scrollDuration?: number) => void;
export type ScrollViewRequiredProps = {
    /** components/nodes content. If you need to scroll programmatically pass a function and save `scrollTo(x, y, milliseconds)` callback for later use (it will be passed as first argument) ex: `(scrollTo) => { this.scrollTo = scrollTo; return <MyScrollViewContent />; }` */
    children: Children | ((scrollTo: ScrollTo) => Children);
};
export type ScrollViewDefaultedProps = ScrollViewRequiredProps & ScrollViewDefaultProps & React.HTMLAttributes<HTMLDivElement>;
export declare namespace ScrollView {
    type Props = ScrollViewRequiredProps & Partial<ScrollViewDefaultProps> & React.HTMLAttributes<HTMLDivElement>;
}
/**
 * ### Utility component to make scrolling easier:
 * - can stop scroll propagation
 * - smooth programmatic scroll with 22 easing functions (see `easingFunctions.js`)
 * - out of the box momentum scrolling on iOS
 */
export declare class ScrollView extends React.Component<ScrollView.Props> {
    private scrollView;
    private lastY;
    static defaultProps: ScrollViewDefaultProps;
    getEventListeners: () => {
        onWheel: React.ReactEventHandler<HTMLDivElement>;
        onScroll: (React.WheelEventHandler<HTMLDivElement> & React.UIEventHandler<HTMLDivElement>) | undefined;
        onTouchStart: React.TouchEventHandler<HTMLDivElement>;
        onTouchEnd: React.TouchEventHandler<HTMLDivElement>;
        onTouchMove: React.ReactEventHandler<HTMLDivElement>;
    };
    isEventInsideScrollView: (el: Node) => boolean;
    initializeTouchEventDirection: React.TouchEventHandler<HTMLDivElement>;
    clearTouchEventDirection: React.TouchEventHandler<HTMLDivElement>;
    stopScrollPropagation: React.ReactEventHandler<HTMLDivElement>;
    isAtTop: () => boolean | null;
    isAtBottom: () => boolean;
    computeStyle: () => React.CSSProperties;
    scrollTo: ScrollTo;
    _scrollTo: (x: number, y: number, scrollDuration: number, startTime: number, startX: number, startY: number) => void;
    _onScroll: React.ReactEventHandler<HTMLDivElement>;
    render(): JSX.Element;
}
