"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScrollView = void 0;
var React = __importStar(require("react"));
var omit = require("lodash/omit");
var easingFunctions_1 = __importDefault(require("./easingFunctions"));
var Props = {
    children: true,
    scrollX: true,
    scrollY: true,
    scrollPropagation: true,
    easing: true,
    onScroll: true,
    style: true
};
/**
 * ### Utility component to make scrolling easier:
 * - can stop scroll propagation
 * - smooth programmatic scroll with 22 easing functions (see `easingFunctions.js`)
 * - out of the box momentum scrolling on iOS
 */
var ScrollView = /** @class */ (function (_super) {
    __extends(ScrollView, _super);
    function ScrollView() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.scrollView = null;
        _this.lastY = 0;
        _this.getEventListeners = function () {
            return {
                onWheel: _this._onScroll,
                onScroll: _this.props.onScroll,
                onTouchStart: _this.initializeTouchEventDirection,
                onTouchEnd: _this.clearTouchEventDirection,
                onTouchMove: _this._onScroll
            };
        };
        _this.isEventInsideScrollView = function (el) {
            if (el === _this.scrollView) {
                return true;
            }
            else if (el.parentNode) {
                return _this.isEventInsideScrollView(el.parentNode);
            }
            else {
                return false;
            }
        };
        _this.initializeTouchEventDirection = function (e) {
            _this.lastY = e.touches[0].clientY;
        };
        _this.clearTouchEventDirection = function () {
            _this.lastY = 0;
        };
        _this.stopScrollPropagation = function (_a) {
            var e = _a.nativeEvent;
            var el = (e.target || e.srcElement);
            var isEventInsideScrollView = _this.isEventInsideScrollView(el);
            if (isEventInsideScrollView) {
                // const { scrollTop, scrollHeight, offsetHeight } = this.scrollView;
                var up = false;
                if (e instanceof TouchEvent) {
                    var clientY = e.touches[0].clientY;
                    up = clientY > _this.lastY;
                    _this.lastY = clientY;
                }
                else if (e instanceof WheelEvent) {
                    // not sure why `wheelDelta` is not there
                    up = e.wheelDelta > 0;
                }
                var down = !up;
                if ((down && _this.isAtBottom()) || (up && _this.isAtTop())) {
                    e.preventDefault();
                }
            }
        };
        _this.isAtTop = function () { return _this.scrollView && _this.scrollView.scrollTop === 0; };
        _this.isAtBottom = function () {
            if (!_this.scrollView)
                return false;
            var _a = _this.scrollView, scrollTop = _a.scrollTop, scrollHeight = _a.scrollHeight, clientHeight = _a.clientHeight;
            return scrollTop + clientHeight === scrollHeight;
        };
        _this.computeStyle = function () {
            var _a = _this.props, scrollX = _a.scrollX, scrollY = _a.scrollY, style = _a.style;
            return __assign({ overflowY: scrollY ? 'scroll' : undefined /* has to be scroll for iOS, not auto */, overflowX: scrollX ? 'scroll' : undefined /* has to be scroll for iOS, not auto */, WebkitOverflowScrolling: 'touch' }, style);
        };
        _this.scrollTo = function (_x, _y, scrollDuration) {
            if (!_this.scrollView)
                return;
            var _a = _this.scrollView, scrollTop = _a.scrollTop, scrollLeft = _a.scrollLeft;
            var x = _x || scrollLeft;
            var y = _y || scrollTop;
            _this._scrollTo(x, y, scrollDuration || 0, Date.now(), scrollLeft, scrollTop);
        };
        _this._scrollTo = function (x, y, scrollDuration, startTime, startX, startY) {
            if (!_this.scrollView)
                return;
            var easingType = _this.props.easing;
            if (scrollDuration > 0) {
                var _a = _this.scrollView, scrollTop = _a.scrollTop, scrollLeft = _a.scrollLeft;
                var easingFunction = easingFunctions_1.default[easingType];
                if ((typeof x === 'number' && scrollLeft !== x) ||
                    (typeof y === 'number' && scrollTop !== y)) {
                    var currentTime = Math.min(scrollDuration, Date.now() - startTime);
                    var distanceX = x - startX;
                    var distanceY = y - startY;
                    _this.scrollView.scrollLeft = easingFunction(currentTime, startX, distanceX, scrollDuration);
                    _this.scrollView.scrollTop = easingFunction(currentTime, startY, distanceY, scrollDuration);
                    requestAnimationFrame(function () {
                        return _this._scrollTo(x, y, scrollDuration, startTime, startX, startY);
                    });
                }
            }
            else {
                _this.scrollView.scrollLeft = x;
                _this.scrollView.scrollTop = y;
            }
        };
        _this._onScroll = function (e) {
            if (!_this.props.scrollPropagation) {
                _this.stopScrollPropagation(e);
            }
        };
        return _this;
    }
    ScrollView.prototype.render = function () {
        var _this = this;
        var props = omit(this.props, Object.keys(Props));
        var children = this.props.children;
        return (React.createElement("div", __assign({}, props, this.getEventListeners(), { style: this.computeStyle(), ref: function (sv) {
                _this.scrollView = sv;
            } }), typeof children === 'function' ? children(this.scrollTo) : children));
    };
    ScrollView.defaultProps = {
        scrollX: true,
        scrollY: true,
        scrollPropagation: true,
        easing: 'easeInOutQuad',
        onScroll: function () { },
        style: {}
    };
    return ScrollView;
}(React.Component));
exports.ScrollView = ScrollView;
