import * as React from 'react';
export type ScrollViewDefaultProps<CP extends React.HTMLAttributes<any>, ICP extends React.HTMLAttributes<any>> = {
    /** component to use as the wrapper */
    component: keyof React.ReactHTML | React.ComponentType<CP>;
    /** props to pass to the wrapper component */
    componentProps: CP;
    /** component to use as the inner wrapper */
    innerComponent: keyof React.ReactHTML | React.ComponentType<ICP>;
    /** props to pass to the inner wrapper component */
    innerComponentProps: ICP;
    /** force ScrollView to use `gemini-scrollbar`s */
    forceGemini: boolean;
    /** style to pass to the wrapper component */
    style: React.CSSProperties;
};
export type ScrollViewRequiredProps = {
    /** what to render inside the scroll view */
    children: any;
    /** whether to automatically show scrollbars */
    autoshow?: boolean;
    /** className to pass to the wrapper component */
    className?: string;
};
export type State = {
    isVerticalScrollbarVisible: boolean;
    isHorizontalScrollbarVisible: boolean;
};
export type ScrollViewDefaultedProps<CP extends React.HTMLAttributes<any>, ICP extends React.HTMLAttributes<any>> = ScrollViewRequiredProps & ScrollViewDefaultProps<CP, ICP>;
export declare namespace ScrollView {
    type Props<CP extends React.HTMLAttributes<any>, ICP extends React.HTMLAttributes<any>> = ScrollViewRequiredProps & Partial<ScrollViewDefaultProps<CP, ICP>>;
}
/** A scrollable view to be used in projects where you want the same scrollbar style across different browsers */
export declare class ScrollView<CP extends React.HTMLAttributes<any>, ICP extends React.HTMLAttributes<any>> extends React.PureComponent<ScrollView.Props<CP, ICP>, State> {
    static defaultProps: ScrollViewDefaultProps<React.HTMLAttributes<HTMLDivElement>, React.HTMLAttributes<HTMLDivElement>>;
    state: {
        isVerticalScrollbarVisible: boolean;
        isHorizontalScrollbarVisible: boolean;
    };
    private scrollbar;
    private verticalThumb;
    private horizontalThumb;
    componentDidMount(): void;
    componentDidUpdate(): void;
    componentWillUnmount(): void;
    saveScrollbarsState(): void;
    wrapperRenderer: (props: CP) => React.DetailedReactHTMLElement<React.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>;
    innerWrapperRenderer: (props: ICP) => React.DetailedReactHTMLElement<React.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>;
    render(): JSX.Element;
}
