/// <reference types="lodash" />
import * as React from 'react';
import { ObjectOverwrite, Children } from '../utils';
import { Popover } from '../Popover/Popover';
export type TextOverflowDefaultProps = {
    /** tooltip delay if the component is lazy */
    delayWhenLazy: number;
    /** whether the tooltip appearance should be delayed after mouse entering or not */
    lazy: boolean;
};
export type TextOverflowRequiredProps = {
    /** this is the full string */
    label: string | number;
    /** in case you want to use a custom component (like a `Tooltip`) to render the full content which is passed as the first argument */
    children?: (self: Children, isOpen?: boolean) => Children;
    /** additional props for Popover component used to display the entire text */
    popover?: ObjectOverwrite<Popover.Props['popover'], {
        content?: undefined;
    }>;
    id?: string;
    className?: string;
    style?: React.CSSProperties;
};
export declare namespace TextOverflow {
    type Props = TextOverflowRequiredProps & Partial<TextOverflowDefaultProps>;
}
export type State = {
    isOverflowing: boolean;
    isHovering: boolean;
};
/**
 * Text view which, if string content is too large, trims it and shows the full content on "hover".
 */
export declare class TextOverflow extends React.Component<TextOverflow.Props, State> {
    private text;
    private textWithoutEllipsis;
    static defaultProps: TextOverflowDefaultProps;
    state: {
        isOverflowing: boolean;
        isHovering: boolean;
    };
    componentDidMount(): void;
    componentDidUpdate(prevProps: TextOverflow.Props): void;
    reset: () => void;
    logWarnings: () => void;
    getElementWidth: (element?: Element) => number;
    verifyOverflow: ({ force, reset }?: {
        force?: boolean | undefined;
        reset?: boolean | undefined;
    }) => void;
    _onMouseEvent: (type: string) => false | void;
    onMouseEventDebounced: ((type: string) => false | void) & _.Cancelable;
    onMouseEvent: React.MouseEventHandler<Element>;
    onMouseEnter: () => void;
    onMouseLeave: React.MouseEventHandler<Element>;
    onResize: () => void;
    getContent: () => JSX.Element;
    templateOverflow: () => JSX.Element;
    templeteStandard: () => JSX.Element;
    render(): JSX.Element;
}
