import * as React from 'react';
import { SingleDropdownProps } from '../Dropdown';
export declare const H24 = "24h";
export declare const H12 = "12h";
export declare const inputError: {};
declare const toOption: (time: TimePicker.TimeAndFormat) => TimeDropdownOption;
declare const parseInTimeFormat: (inputStr: string, timeFormat: TimePicker.TimeFormat) => TimePicker.OnChangeInput;
declare const createTimeList: ({ hours, minutes }: TimePicker.Time, timeFormat: TimePicker.TimeFormat) => Array<TimePicker.TimeAndFormat>;
type FilterTimeInput = {
    originalInput: string;
    minTime: TimePicker.Time;
    maxTime: TimePicker.Time;
};
declare const filterTime: ({ originalInput, minTime, maxTime }: FilterTimeInput) => (time: TimePicker.TimeAndFormat) => boolean;
type MakeOptionsInput = {
    timeFormat: TimePicker.TimeFormat;
    minTime: TimePicker.Time;
    maxTime: TimePicker.Time;
    userValue?: TimePicker.Time;
};
declare const makeOptions: ({ minTime, maxTime, timeFormat, userValue }: MakeOptionsInput, inputValue: string) => TimeDropdownOption[];
export interface RequiredProps {
    /** onChange handler. It takes an object */
    onChange: (time?: TimePicker.OnChangeInput) => void;
    /** value provided as input. Have to be passed in 24h format. E.g. { hours: 10, minutes: 30 } */
    value?: TimePicker.Time;
    timeFormatter?: TimePicker.TimeFormatter;
    /** optionally disable the control */
    disabled?: boolean;
    className?: string;
    id?: string;
}
export interface DefaultProps {
    /** field placeholder, displayed when there's no value. Default[--:--] */
    placeholder: string;
    /** format in which options are displayed (12h|24h) */
    timeFormat: TimePicker.TimeFormat;
    /** minimum value. Have to be passed in 24h format. Default [00:00] */
    minTime: TimePicker.Time;
    /** maximum value. Have to be passed in 24h format. Default [23:59] */
    maxTime: TimePicker.Time;
    /** enable the search feature */
    searchable: boolean;
    /** dropdown size */
    size: 'medium' | 'small';
    /** whether the menu should open on top or bottom */
    menuPosition: SingleDropdownProps<TimeDropdownOption>['menuPlacement'];
    /** object of custom compoents for react select */
    components: SingleDropdownProps<TimeDropdownOption>['components'];
}
export declare namespace TimePicker {
    type Time = {
        hours: number;
        minutes: number;
    };
    type TimeFormat = '12h' | '24h';
    type TimeAndFormat = Time & {
        timeFormat: TimeFormat;
    };
    type TimeFormatter = (t: TimeAndFormat) => JSX.Element;
    type OnChangeInput = {
        originalInput?: string;
    } & Partial<Time>;
    type Props = RequiredProps & Partial<DefaultProps>;
}
type TimeDropdownOption = {
    time: TimePicker.TimeAndFormat;
    value: string;
    label: string;
};
export declare class TimePicker extends React.Component<TimePicker.Props, {
    inputValue: string;
}> {
    static defaultProps: {
        placeholder: string;
        timeFormat: string;
        minTime: {
            hours: number;
            minutes: number;
        };
        maxTime: {
            hours: number;
            minutes: number;
        };
        searchable: boolean;
        size: string;
        menuPosition: string;
    };
    state: {
        inputValue: string;
    };
    componentDidMount(): void;
    _onChange: (value: TimeDropdownOption) => void;
    updateInputValue: (inputValue: string) => void;
    render(): JSX.Element;
}
export { toOption, parseInTimeFormat, createTimeList, filterTime, makeOptions };
