import * as React from 'react';
import ReactTransitionGroup from 'react-transition-group/TransitionGroup';
import { Children } from '../utils';
import { TransitionWrapper } from '../TransitionWrapper/TransitionWrapper';
export type ToasterDefaultProps = {
    /** custom settings for `ReactTransitionGroup` */
    transitionGroup: ReactTransitionGroup.TransitionGroupProps;
    /** toaster position on screen */
    position: 'top-left' | 'top-right' | 'bottom-left' | 'bottom-right';
};
export type ToasterRequiredProps = {
    /** list of toasts (any node with a unique key) */
    children: Children[];
    /** id of the element you want to render the `Toaster` in */
    attachTo?: string;
    /** object with style for each transition event (used by `TransitionWrapper`) */
    transitionStyles?: TransitionWrapper.TransitionStyles;
    /** duration of enter transition in milliseconds (used by `TransitionWrapper`) */
    transitionEnterTimeout: number;
    /** duration of leave transition in milliseconds (used by `TransitionWrapper`) */
    transitionLeaveTimeout: number;
    id?: string;
    className?: string;
    style?: React.CSSProperties;
};
export declare namespace Toaster {
    type Props = ToasterRequiredProps & Partial<ToasterDefaultProps>;
}
/**
 * Renders and animates toasts (children) inline or in a portal
 */
export declare class Toaster extends React.Component<Toaster.Props> {
    private toaster;
    static defaultProps: ToasterDefaultProps;
    componentWillMount(): void;
    componentDidMount(): void;
    componentWillUnmount(): void;
    getTranslationStyle(i: number): React.CSSProperties;
    getToasts: () => JSX.Element[] | null | undefined;
    appendToaster: () => void;
    removeToaster: () => void;
    getToaster: () => JSX.Element;
    renderToaster: () => void;
    render(): JSX.Element | null;
    componentDidUpdate(prevProps: Toaster.Props): void;
}
