import * as React from 'react';
export type TransitionWrapperDefaultProps<CP> = {
    /** object with inline-style for each transition event. It's also possible to use `css` classes (formatted in kebab-case) */
    transitionStyles: TransitionWrapper.TransitionStyles;
    /** custom component to be used as wrapper for `children`. Can be either an html tag name string (eg. 'div', 'span', etc), or a `ReactClass` (eg. `FlexView`) */
    component: keyof React.ReactHTML | React.ComponentClass<CP>;
    /** callback for componentDidLeave: useful if you need to do some cleanup */
    onLeave: () => void;
    style: React.CSSProperties;
};
export type TransitionWrapperRequiredProps = {
    /** the component you want to animate (it must have a unique "key") */
    children: JSX.Element;
    /** duration of enter transition in milliseconds */
    transitionEnterTimeout: number;
    /** duration of leave transition in milliseconds */
    transitionLeaveTimeout: number;
    className?: string;
};
export type TransitionWrapperDefaultedProps<CP> = TransitionWrapperRequiredProps & TransitionWrapperDefaultProps<CP> & {
    [k in keyof CP]: CP[k];
};
export declare namespace TransitionWrapper {
    type TransitionStyles = {
        enter?: React.CSSProperties;
        enterActive?: React.CSSProperties;
        default?: React.CSSProperties;
        leave?: React.CSSProperties;
        leaveActive?: React.CSSProperties;
    };
    type Props<CP> = TransitionWrapperRequiredProps & Partial<TransitionWrapperDefaultProps<CP>> & {
        [k in keyof CP]: CP[k];
    };
}
export type State = {
    animationStart?: React.CSSProperties;
    animationEnd?: React.CSSProperties;
    defaultStyle?: React.CSSProperties;
    transitionClassName?: string;
};
/**
 * To be used with `ReactTransitionGroup` to show transitions for a component
 */
export declare class TransitionWrapper<CP extends {}> extends React.PureComponent<TransitionWrapper.Props<CP>, State> {
    static defaultProps: TransitionWrapperDefaultProps<React.HTMLAttributes<HTMLDivElement>>;
    _replaceState: (state: State) => void;
    startAnimation(anim: 'enter' | 'leave', timeout: number, callback: () => void): void;
    componentWillAppear: (callback: () => void) => void;
    componentDidAppear: () => void;
    componentWillEnter: (callback: () => void) => void;
    componentDidEnter: () => void;
    componentWillLeave: (callback: () => void) => void;
    componentDidLeave: () => void;
    getStyle: () => React.CSSProperties;
    render(): React.DetailedReactHTMLElement<React.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement> | null;
}
